@@ -9,4 +9,5 @@ This module contains visualization subroutines for SP2 data.
 
     plot_wave
 """
-from .plot_wave import plot_wave
+from .plot_wave import plot_wave, plot_waves
+from .data_editor import DataEditor
